"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import collections.abc
import grpc
import grpc.aio
import model.controller.v1alpha.controller_pb2
import typing

_T = typing.TypeVar('_T')

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta):
    ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore
    ...

class ControllerPrivateServiceStub:
    """Controller service responds to incoming controller requests"""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Liveness: grpc.UnaryUnaryMultiCallable[
        model.controller.v1alpha.controller_pb2.LivenessRequest,
        model.controller.v1alpha.controller_pb2.LivenessResponse,
    ]
    """Liveness method receives a LivenessRequest message and returns a
    LivenessResponse message.
    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
    """
    Readiness: grpc.UnaryUnaryMultiCallable[
        model.controller.v1alpha.controller_pb2.ReadinessRequest,
        model.controller.v1alpha.controller_pb2.ReadinessResponse,
    ]
    """Readiness method receives a ReadinessRequest message and returns a
    ReadinessResponse message.
    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
    """
    GetResource: grpc.UnaryUnaryMultiCallable[
        model.controller.v1alpha.controller_pb2.GetResourceRequest,
        model.controller.v1alpha.controller_pb2.GetResourceResponse,
    ]
    """GetResource method receives a GetResourceRequest message
    and returns a GetResourceResponse
    """
    UpdateResource: grpc.UnaryUnaryMultiCallable[
        model.controller.v1alpha.controller_pb2.UpdateResourceRequest,
        model.controller.v1alpha.controller_pb2.UpdateResourceResponse,
    ]
    """UpdateResource method receives a UpdateResourceRequest message
    and returns a UpdateResourceResponse
    """
    DeleteResource: grpc.UnaryUnaryMultiCallable[
        model.controller.v1alpha.controller_pb2.DeleteResourceRequest,
        model.controller.v1alpha.controller_pb2.DeleteResourceResponse,
    ]
    """DeleteResource method receives a DeleteResourceRequest message
    and returns a DeleteResourceResponse
    """

class ControllerPrivateServiceAsyncStub:
    """Controller service responds to incoming controller requests"""

    Liveness: grpc.aio.UnaryUnaryMultiCallable[
        model.controller.v1alpha.controller_pb2.LivenessRequest,
        model.controller.v1alpha.controller_pb2.LivenessResponse,
    ]
    """Liveness method receives a LivenessRequest message and returns a
    LivenessResponse message.
    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
    """
    Readiness: grpc.aio.UnaryUnaryMultiCallable[
        model.controller.v1alpha.controller_pb2.ReadinessRequest,
        model.controller.v1alpha.controller_pb2.ReadinessResponse,
    ]
    """Readiness method receives a ReadinessRequest message and returns a
    ReadinessResponse message.
    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
    """
    GetResource: grpc.aio.UnaryUnaryMultiCallable[
        model.controller.v1alpha.controller_pb2.GetResourceRequest,
        model.controller.v1alpha.controller_pb2.GetResourceResponse,
    ]
    """GetResource method receives a GetResourceRequest message
    and returns a GetResourceResponse
    """
    UpdateResource: grpc.aio.UnaryUnaryMultiCallable[
        model.controller.v1alpha.controller_pb2.UpdateResourceRequest,
        model.controller.v1alpha.controller_pb2.UpdateResourceResponse,
    ]
    """UpdateResource method receives a UpdateResourceRequest message
    and returns a UpdateResourceResponse
    """
    DeleteResource: grpc.aio.UnaryUnaryMultiCallable[
        model.controller.v1alpha.controller_pb2.DeleteResourceRequest,
        model.controller.v1alpha.controller_pb2.DeleteResourceResponse,
    ]
    """DeleteResource method receives a DeleteResourceRequest message
    and returns a DeleteResourceResponse
    """

class ControllerPrivateServiceServicer(metaclass=abc.ABCMeta):
    """Controller service responds to incoming controller requests"""

    @abc.abstractmethod
    def Liveness(
        self,
        request: model.controller.v1alpha.controller_pb2.LivenessRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.controller.v1alpha.controller_pb2.LivenessResponse, collections.abc.Awaitable[model.controller.v1alpha.controller_pb2.LivenessResponse]]:
        """Liveness method receives a LivenessRequest message and returns a
        LivenessResponse message.
        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
        """
    @abc.abstractmethod
    def Readiness(
        self,
        request: model.controller.v1alpha.controller_pb2.ReadinessRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.controller.v1alpha.controller_pb2.ReadinessResponse, collections.abc.Awaitable[model.controller.v1alpha.controller_pb2.ReadinessResponse]]:
        """Readiness method receives a ReadinessRequest message and returns a
        ReadinessResponse message.
        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
        """
    @abc.abstractmethod
    def GetResource(
        self,
        request: model.controller.v1alpha.controller_pb2.GetResourceRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.controller.v1alpha.controller_pb2.GetResourceResponse, collections.abc.Awaitable[model.controller.v1alpha.controller_pb2.GetResourceResponse]]:
        """GetResource method receives a GetResourceRequest message
        and returns a GetResourceResponse
        """
    @abc.abstractmethod
    def UpdateResource(
        self,
        request: model.controller.v1alpha.controller_pb2.UpdateResourceRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.controller.v1alpha.controller_pb2.UpdateResourceResponse, collections.abc.Awaitable[model.controller.v1alpha.controller_pb2.UpdateResourceResponse]]:
        """UpdateResource method receives a UpdateResourceRequest message
        and returns a UpdateResourceResponse
        """
    @abc.abstractmethod
    def DeleteResource(
        self,
        request: model.controller.v1alpha.controller_pb2.DeleteResourceRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.controller.v1alpha.controller_pb2.DeleteResourceResponse, collections.abc.Awaitable[model.controller.v1alpha.controller_pb2.DeleteResourceResponse]]:
        """DeleteResource method receives a DeleteResourceRequest message
        and returns a DeleteResourceResponse
        """

def add_ControllerPrivateServiceServicer_to_server(servicer: ControllerPrivateServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# generated by datamodel-codegen:
#   filename:  googlesearch_task_search_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import List, Optional


@dataclass
class Result:
    link: str
    snippet: str
    title: str
    link_html: Optional[str] = None
    link_text: Optional[str] = None


@dataclass
class Output:
    results: List[Result]



import argparse
import hashlib
import os
import platform
import shutil
import subprocess
import tempfile

import ray
import yaml

import instill
from instill.helpers.const import DEFAULT_DEPENDENCIES
from instill.utils.logger import Logger

if __name__ == "__main__":
    Logger.i("[Instill Builder] Setup docker...")
    if platform.machine() in ("i386", "AMD64", "x86_64"):
        default_platform = "amd64"
    else:
        default_platform = platform.machine()
    parser = argparse.ArgumentParser()
    parser.add_argument(
        "--no-cache",
        help="build the image without cache",
        action="store_true",
        required=False,
    )
    parser.add_argument(
        "--target-arch",
        help="target platform architecture for the model image, default to host",
        default=default_platform,
        choices=["arm64", "amd64"],
        required=False,
    )

    try:
        args = parser.parse_args()

        Logger.i("[Instill Builder] Loading config file...")
        with open("instill.yaml", "r", encoding="utf8") as f:
            Logger.i("[Instill Builder] Parsing config file...")
            config = yaml.safe_load(f)

        build = config["build"]
        repo = config["repo"]
        tag = (
            config["tag"]
            if config["tag"] is not None and config["tag"] != ""
            else hashlib.sha256().hexdigest()
        )

        python_version = build["python_version"].replace(".", "")
        ray_version = ray.__version__
        instill_version = instill.__version__

        cuda_suffix = "" if not build["gpu"] else "-cu121"

        packages_str = ""
        if not build["python_packages"] is None:
            for p in build["python_packages"]:
                packages_str += p + " "
        for p in DEFAULT_DEPENDENCIES:
            packages_str += p + " "
        packages_str += f"instill-sdk=={instill_version}"

        with tempfile.TemporaryDirectory() as tmpdir:
            shutil.copyfile(
                __file__.replace("build.py", "Dockerfile"), f"{tmpdir}/Dockerfile"
            )
            shutil.copyfile(
                __file__.replace("build.py", ".dockerignore"), f"{tmpdir}/.dockerignore"
            )
            shutil.copytree(os.getcwd(), tmpdir, dirs_exist_ok=True)

            target_arch_suffix = "-aarch64" if args.target_arch == "arm64" else ""

            Logger.i("[Instill Builder] Building model image...")
            command = [
                "docker",
                "buildx",
                "build",
                "--build-arg",
                f"TARGET_ARCH_SUFFIX={target_arch_suffix}",
                "--build-arg",
                f"RAY_VERSION={ray_version}",
                "--build-arg",
                f"PYTHON_VERSION={python_version}",
                "--build-arg",
                f"CUDA_SUFFIX={cuda_suffix}",
                "--build-arg",
                f"PACKAGES={packages_str}",
                "--platform",
                f"linux/{args.target_arch}",
                "-t",
                f"{repo}:{tag}",
                tmpdir,
                "--load",
            ]
            if args.no_cache:
                command.append("--no-cache")
            subprocess.run(
                command,
                check=True,
            )
            Logger.i(f"[Instill Builder] {repo}:{tag} built")
    except subprocess.CalledProcessError as e:
        Logger.e("[Instill Builder] Build failed")
    except Exception as e:
        Logger.e("[Instill Builder] Prepare failed")
        Logger.e(e)
    finally:
        Logger.i("[Instill Builder] Done")



# generated by datamodel-codegen:
#   filename:  huggingface_task_translation_output.json

from __future__ import annotations

from dataclasses import dataclass


@dataclass
class Output:
    translation_text: str



import argparse
import subprocess

import yaml

from instill.utils.logger import Logger

if __name__ == "__main__":
    Logger.i("[Instill Builder] Setup docker...")

    parser = argparse.ArgumentParser()
    parser.add_argument(
        "-u",
        "--url",
        help="image registry url, in the format of host:port, default to docker.io",
        default="docker.io",
        required=False,
    )

    try:
        args = parser.parse_args()

        Logger.i("[Instill Builder] Loading config file...")
        with open("instill.yaml", "r", encoding="utf8") as f:
            Logger.i("[Instill Builder] Parsing config file...")
            config = yaml.safe_load(f)

        registry = args.url
        repo = config["repo"]
        tag = config["tag"]

        subprocess.run(
            ["docker", "tag", f"{repo}:{tag}", f"{registry}/{repo}:{tag}"], check=True
        )
        Logger.i("[Instill Builder] Pushing model image...")
        subprocess.run(["docker", "push", f"{registry}/{repo}:{tag}"], check=True)
        Logger.i(f"[Instill Builder] {registry}/{repo}:{tag} pushed")
    except subprocess.CalledProcessError as e:
        Logger.e("[Instill Builder] Push failed")
    except Exception as e:
        Logger.e("[Instill Builder] Prepare failed")
        Logger.e(e)
    finally:
        Logger.i("[Instill Builder] Done")



# generated by datamodel-codegen:
#   filename:  redis_definitions.json

from __future__ import annotations

from dataclasses import dataclass
from enum import Enum
from typing import Optional, Union


class DisableSSL(Enum):
    disable = 'disable'


@dataclass
class DisableSSLMode:
    mode: DisableSSL


class Enable(Enum):
    verify_full = 'verify-full'


@dataclass
class VerifyFullSSLMode:
    ca_cert: str
    client_cert: str
    client_key: str
    mode: Enable


@dataclass
class RedisConnectorResource:
    host: str
    port: int
    password: Optional[str] = None
    ssl: Optional[bool] = False
    ssl_mode: Optional[Union[DisableSSLMode, VerifyFullSSLMode]] = None
    username: Optional[str] = None



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import core.mgmt.v1beta.mgmt_pb2
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.timestamp_pb2
import sys
import typing
import vdp.pipeline.v1beta.connector_definition_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Connector(google.protobuf.message.Message):
    """A Connector is a type of pipeline component that queries, processes or sends
    the ingested unstructured data to a service or app. Users need to configure
    their connectors (e.g. by providing an API token to a remote service).

    For more information, see
    [Component](https://www.instill.tech/docs/latest/core/concepts/pipeline#pipeline-component)
    in the official documentation.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _View:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ViewEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Connector._View.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        VIEW_UNSPECIFIED: Connector._View.ValueType  # 0
        """Unspecified, equivalent to BASIC."""
        VIEW_BASIC: Connector._View.ValueType  # 1
        """Default view, only includes basic information."""
        VIEW_FULL: Connector._View.ValueType  # 2
        """Full representation."""
        VIEW_CONFIGURATION: Connector._View.ValueType  # 3
        """Contains the connector configuration."""

    class View(_View, metaclass=_ViewEnumTypeWrapper):
        """View defines how a connector is presented."""

    VIEW_UNSPECIFIED: Connector.View.ValueType  # 0
    """Unspecified, equivalent to BASIC."""
    VIEW_BASIC: Connector.View.ValueType  # 1
    """Default view, only includes basic information."""
    VIEW_FULL: Connector.View.ValueType  # 2
    """Full representation."""
    VIEW_CONFIGURATION: Connector.View.ValueType  # 3
    """Contains the connector configuration."""

    class _State:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Connector._State.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATE_UNSPECIFIED: Connector._State.ValueType  # 0
        """Unspecified."""
        STATE_DISCONNECTED: Connector._State.ValueType  # 1
        """Disconnected."""
        STATE_CONNECTED: Connector._State.ValueType  # 2
        """Connected."""
        STATE_ERROR: Connector._State.ValueType  # 3
        """The connector suffered an error."""

    class State(_State, metaclass=_StateEnumTypeWrapper):
        """State describes the state of the connector."""

    STATE_UNSPECIFIED: Connector.State.ValueType  # 0
    """Unspecified."""
    STATE_DISCONNECTED: Connector.State.ValueType  # 1
    """Disconnected."""
    STATE_CONNECTED: Connector.State.ValueType  # 2
    """Connected."""
    STATE_ERROR: Connector.State.ValueType  # 3
    """The connector suffered an error."""

    class _Visibility:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _VisibilityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Connector._Visibility.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        VISIBILITY_UNSPECIFIED: Connector._Visibility.ValueType  # 0
        """Unspecified, equivalent to PRIVATE."""
        VISIBILITY_PRIVATE: Connector._Visibility.ValueType  # 1
        """Only the user can see the connector."""
        VISIBILITY_PUBLIC: Connector._Visibility.ValueType  # 2
        """Other users can see the connector."""

    class Visibility(_Visibility, metaclass=_VisibilityEnumTypeWrapper):
        """Visibility defines who can access the connector."""

    VISIBILITY_UNSPECIFIED: Connector.Visibility.ValueType  # 0
    """Unspecified, equivalent to PRIVATE."""
    VISIBILITY_PRIVATE: Connector.Visibility.ValueType  # 1
    """Only the user can see the connector."""
    VISIBILITY_PUBLIC: Connector.Visibility.ValueType  # 2
    """Other users can see the connector."""

    NAME_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    CONNECTOR_DEFINITION_NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CONFIGURATION_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    TOMBSTONE_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    VISIBILITY_FIELD_NUMBER: builtins.int
    CONNECTOR_DEFINITION_FIELD_NUMBER: builtins.int
    DELETE_TIME_FIELD_NUMBER: builtins.int
    OWNER_NAME_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the connector, defined by its ID.
    - Format: `connectors/{id}`.
    """
    uid: builtins.str
    """Connector UUID."""
    id: builtins.str
    """Connector resource ID (used in `name` as the last segment). This conforms
    to RFC-1034, which restricts to letters, numbers, and hyphen, with the
    first character a letter, the last a letter or a number, and a 63
    character maximum.
    """
    connector_definition_name: builtins.str
    """Connector definition that describes the connector configuration."""
    type: vdp.pipeline.v1beta.connector_definition_pb2.ConnectorType.ValueType
    """Connector type."""
    description: builtins.str
    """Connector description."""
    @property
    def configuration(self) -> google.protobuf.struct_pb2.Struct:
        """Connector configuration in JSON format."""
    state: global___Connector.State.ValueType
    """Connector state."""
    tombstone: builtins.bool
    """Connector tombstone. If true, this configuration is permanently off.
    Otherwise, the configuration is active.
    """
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Connector creation time."""
    @property
    def update_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Connector update time."""
    visibility: global___Connector.Visibility.ValueType
    """Connector visibility."""
    @property
    def connector_definition(self) -> vdp.pipeline.v1beta.connector_definition_pb2.ConnectorDefinition:
        """Embed content of the ConnectorDefinition."""
    @property
    def delete_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Connector deletion time."""
    owner_name: builtins.str
    """Owner name."""
    @property
    def owner(self) -> core.mgmt.v1beta.mgmt_pb2.Owner:
        """Connector owner."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        uid: builtins.str = ...,
        id: builtins.str = ...,
        connector_definition_name: builtins.str = ...,
        type: vdp.pipeline.v1beta.connector_definition_pb2.ConnectorType.ValueType = ...,
        description: builtins.str | None = ...,
        configuration: google.protobuf.struct_pb2.Struct | None = ...,
        state: global___Connector.State.ValueType = ...,
        tombstone: builtins.bool = ...,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        update_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        visibility: global___Connector.Visibility.ValueType = ...,
        connector_definition: vdp.pipeline.v1beta.connector_definition_pb2.ConnectorDefinition | None = ...,
        delete_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        owner_name: builtins.str = ...,
        owner: core.mgmt.v1beta.mgmt_pb2.Owner | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_description", b"_description", "_owner", b"_owner", "configuration", b"configuration", "connector_definition", b"connector_definition", "create_time", b"create_time", "delete_time", b"delete_time", "description", b"description", "owner", b"owner", "update_time", b"update_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_description", b"_description", "_owner", b"_owner", "configuration", b"configuration", "connector_definition", b"connector_definition", "connector_definition_name", b"connector_definition_name", "create_time", b"create_time", "delete_time", b"delete_time", "description", b"description", "id", b"id", "name", b"name", "owner", b"owner", "owner_name", b"owner_name", "state", b"state", "tombstone", b"tombstone", "type", b"type", "uid", b"uid", "update_time", b"update_time", "visibility", b"visibility"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_description", b"_description"]) -> typing_extensions.Literal["description"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_owner", b"_owner"]) -> typing_extensions.Literal["owner"] | None: ...

global___Connector = Connector

@typing_extensions.final
class ListConnectorsRequest(google.protobuf.message.Message):
    """/////////////////////////////////////////////////////////////////////
    RPC messages
    /////////////////////////////////////////////////////////////////////

    ListConnectorsRequest represents a request to list
    connectors
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    SHOW_DELETED_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of connectors to return. The service may return fewer
    than this value. If unspecified, at most 10 connectors will be returned.
    The maximum value is 100; values above 100 will be coerced to 100.
    """
    page_token: builtins.str
    """Page token."""
    view: global___Connector.View.ValueType
    """View allows clients to specify the desired resource view in the response."""
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter
    expression.
    - Example: `create_time>timestamp("2000-06-19T23:31:08.657Z")`.
    """
    show_deleted: builtins.bool
    """Include soft-deleted connectors in the result."""
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        view: global___Connector.View.ValueType | None = ...,
        filter: builtins.str | None = ...,
        show_deleted: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "_show_deleted", b"_show_deleted", "_view", b"_view", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "show_deleted", b"show_deleted", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "_show_deleted", b"_show_deleted", "_view", b"_view", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "show_deleted", b"show_deleted", "view", b"view"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_token", b"_page_token"]) -> typing_extensions.Literal["page_token"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_show_deleted", b"_show_deleted"]) -> typing_extensions.Literal["show_deleted"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___ListConnectorsRequest = ListConnectorsRequest

@typing_extensions.final
class ListConnectorsResponse(google.protobuf.message.Message):
    """ListConnectorsResponse represents a response for a list of
    connectors
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTORS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    @property
    def connectors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Connector]:
        """A list of connector resources."""
    next_page_token: builtins.str
    """Next page token."""
    total_size: builtins.int
    """Total number of connectors."""
    def __init__(
        self,
        *,
        connectors: collections.abc.Iterable[global___Connector] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["connectors", b"connectors", "next_page_token", b"next_page_token", "total_size", b"total_size"]) -> None: ...

global___ListConnectorsResponse = ListConnectorsResponse

@typing_extensions.final
class LookUpConnectorRequest(google.protobuf.message.Message):
    """LookUpConnectorRequest represents a request by an admin to query a connector
    by its UID.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PERMALINK_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    permalink: builtins.str
    """The permalink of the connector, which allows its access by UID.
    - Format: `connectors/{uid}`.
    """
    view: global___Connector.View.ValueType
    """View allows clients to specify the desired connector view in the response."""
    def __init__(
        self,
        *,
        permalink: builtins.str = ...,
        view: global___Connector.View.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_view", b"_view", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_view", b"_view", "permalink", b"permalink", "view", b"view"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___LookUpConnectorRequest = LookUpConnectorRequest

@typing_extensions.final
class LookUpConnectorResponse(google.protobuf.message.Message):
    """LookUpConnectorResponse represents a response for a connector."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_FIELD_NUMBER: builtins.int
    @property
    def connector(self) -> global___Connector:
        """The requested connector."""
    def __init__(
        self,
        *,
        connector: global___Connector | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> None: ...

global___LookUpConnectorResponse = LookUpConnectorResponse

@typing_extensions.final
class CreateUserConnectorRequest(google.protobuf.message.Message):
    """CreateUserConnectorRequest represents a request from a user to create a
    connector.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    @property
    def connector(self) -> global___Connector:
        """The properties of the connector to be created."""
    parent: builtins.str
    """The parent resource, i.e., the user that creates the connector.
    - Format: `users/{user.id}`.
    """
    def __init__(
        self,
        *,
        connector: global___Connector | None = ...,
        parent: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector", b"connector", "parent", b"parent"]) -> None: ...

global___CreateUserConnectorRequest = CreateUserConnectorRequest

@typing_extensions.final
class CreateUserConnectorResponse(google.protobuf.message.Message):
    """CreateUserConnectorResponse contains the created connector."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_FIELD_NUMBER: builtins.int
    @property
    def connector(self) -> global___Connector:
        """The created connector resource."""
    def __init__(
        self,
        *,
        connector: global___Connector | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> None: ...

global___CreateUserConnectorResponse = CreateUserConnectorResponse

@typing_extensions.final
class ListUserConnectorsRequest(google.protobuf.message.Message):
    """ListUserConnectorsRequest represents a request to list the connectors of a
    user.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    SHOW_DELETED_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of connectors to return. If this parameter is
    unspecified, at most 10 connectors will be returned. The cap value for this
    parameter is 100 (i.e. any value above that will be coerced to 100).
    """
    page_token: builtins.str
    """Page token."""
    view: global___Connector.View.ValueType
    """View allows clients to specify the desired resource view in the response."""
    filter: builtins.str
    """Filter expression to list connectors"""
    parent: builtins.str
    """The parent resource, i.e., the user that created the connectors.
    - Format: `users/{user.id}`.
    """
    show_deleted: builtins.bool
    """Include soft-deleted connectors in the result."""
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        view: global___Connector.View.ValueType | None = ...,
        filter: builtins.str | None = ...,
        parent: builtins.str = ...,
        show_deleted: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "_show_deleted", b"_show_deleted", "_view", b"_view", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "show_deleted", b"show_deleted", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "_show_deleted", b"_show_deleted", "_view", b"_view", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "parent", b"parent", "show_deleted", b"show_deleted", "view", b"view"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_token", b"_page_token"]) -> typing_extensions.Literal["page_token"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_show_deleted", b"_show_deleted"]) -> typing_extensions.Literal["show_deleted"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___ListUserConnectorsRequest = ListUserConnectorsRequest

@typing_extensions.final
class ListUserConnectorsResponse(google.protobuf.message.Message):
    """ListUserConnectorsResponse contains a list of connectors."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTORS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    @property
    def connectors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Connector]:
        """A list of connector resources."""
    next_page_token: builtins.str
    """Next page token."""
    total_size: builtins.int
    """Total count of connectors"""
    def __init__(
        self,
        *,
        connectors: collections.abc.Iterable[global___Connector] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["connectors", b"connectors", "next_page_token", b"next_page_token", "total_size", b"total_size"]) -> None: ...

global___ListUserConnectorsResponse = ListUserConnectorsResponse

@typing_extensions.final
class GetUserConnectorRequest(google.protobuf.message.Message):
    """GetUserConnectorRequest represents a request to fetch the details of a
    connector owned by a user.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the connector, which allows its access by parent user
    and ID.
    - Format: `users/{user.id}/connectors/{connector.id}`.
    """
    view: global___Connector.View.ValueType
    """View allows clients to specify the desired resource view in the response."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        view: global___Connector.View.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_view", b"_view", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_view", b"_view", "name", b"name", "view", b"view"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___GetUserConnectorRequest = GetUserConnectorRequest

@typing_extensions.final
class GetUserConnectorResponse(google.protobuf.message.Message):
    """GetUserConnectorResponse contains the requested connector."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_FIELD_NUMBER: builtins.int
    @property
    def connector(self) -> global___Connector:
        """The connector resource."""
    def __init__(
        self,
        *,
        connector: global___Connector | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> None: ...

global___GetUserConnectorResponse = GetUserConnectorResponse

@typing_extensions.final
class UpdateUserConnectorRequest(google.protobuf.message.Message):
    """UpdateUserConnectorRequest represents a request to update a connector owned
    by a user.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    @property
    def connector(self) -> global___Connector:
        """The connector fields that will replace the existing ones."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """The update mask specifies the subset of fields that should be modified.

        For more information about this field, see
        https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#field-mask.
        """
    def __init__(
        self,
        *,
        connector: global___Connector | None = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector", b"connector", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector", b"connector", "update_mask", b"update_mask"]) -> None: ...

global___UpdateUserConnectorRequest = UpdateUserConnectorRequest

@typing_extensions.final
class UpdateUserConnectorResponse(google.protobuf.message.Message):
    """UpdateUserConnectorResponse contains the updated connector."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_FIELD_NUMBER: builtins.int
    @property
    def connector(self) -> global___Connector:
        """The updated connector resource."""
    def __init__(
        self,
        *,
        connector: global___Connector | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> None: ...

global___UpdateUserConnectorResponse = UpdateUserConnectorResponse

@typing_extensions.final
class DeleteUserConnectorRequest(google.protobuf.message.Message):
    """DeleteUserConnectorRequest represents a request to delete a connector owned
    by a user.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the connector, which allows its access by parent user
    and ID.
    - Format: `users/{user.id}/connectors/{connector.id}`.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DeleteUserConnectorRequest = DeleteUserConnectorRequest

@typing_extensions.final
class DeleteUserConnectorResponse(google.protobuf.message.Message):
    """DeleteUserConnectorResponse is an empty response."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteUserConnectorResponse = DeleteUserConnectorResponse

@typing_extensions.final
class ConnectUserConnectorRequest(google.protobuf.message.Message):
    """ConnectUserConnectorRequest represents a request to connect a connector
    owned by a user.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the connector, which allows its access by parent user
    and ID.
    - Format: `users/{user.id}/connectors/{connector.id}`.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___ConnectUserConnectorRequest = ConnectUserConnectorRequest

@typing_extensions.final
class ConnectUserConnectorResponse(google.protobuf.message.Message):
    """ConnectUserConnectorResponse contains the connector details."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_FIELD_NUMBER: builtins.int
    @property
    def connector(self) -> global___Connector:
        """The connector resource."""
    def __init__(
        self,
        *,
        connector: global___Connector | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> None: ...

global___ConnectUserConnectorResponse = ConnectUserConnectorResponse

@typing_extensions.final
class DisconnectUserConnectorRequest(google.protobuf.message.Message):
    """DisconnectUserConnectorRequest represents a request to disconnect a
    connector owned by a user.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the connector, which allows its access by parent user
    and ID.
    - Format: `users/{user.id}/connectors/{connector.id}`.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DisconnectUserConnectorRequest = DisconnectUserConnectorRequest

@typing_extensions.final
class DisconnectUserConnectorResponse(google.protobuf.message.Message):
    """DisconnectUserConnectorResponse contains the connector details."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_FIELD_NUMBER: builtins.int
    @property
    def connector(self) -> global___Connector:
        """A connector"""
    def __init__(
        self,
        *,
        connector: global___Connector | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> None: ...

global___DisconnectUserConnectorResponse = DisconnectUserConnectorResponse

@typing_extensions.final
class RenameUserConnectorRequest(google.protobuf.message.Message):
    """RenameUserConnectorRequest represents a request to rename the name of a
    connector owned by a user.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    NEW_CONNECTOR_ID_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the connector, which allows its access by parent user
    and ID.
    - Format: `users/{user.id}/connectors/{connector.id}`.
    """
    new_connector_id: builtins.str
    """The new resource ID. This will transform the resource name into
    `users/{user.id}/connectors/{new_connector_id}`.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        new_connector_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "new_connector_id", b"new_connector_id"]) -> None: ...

global___RenameUserConnectorRequest = RenameUserConnectorRequest

@typing_extensions.final
class RenameUserConnectorResponse(google.protobuf.message.Message):
    """RenameUserConnectorResponse contains a renamed connector."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_FIELD_NUMBER: builtins.int
    @property
    def connector(self) -> global___Connector:
        """The renamed connector resource."""
    def __init__(
        self,
        *,
        connector: global___Connector | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> None: ...

global___RenameUserConnectorResponse = RenameUserConnectorResponse

@typing_extensions.final
class ExecuteUserConnectorRequest(google.protobuf.message.Message):
    """ExecuteUserConnectorRequest represents a request to execute a connector
    owned by a user.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    TASK_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the connector, which allows its access by parent user
    and ID.
    - Format: `users/{user.id}/connectors/{connector.id}`.
    """
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Connector input parameters."""
    task: builtins.str
    """Task to be passed to the connector (e.g. `TASK_TEXT_GENERATION`)."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        inputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        task: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["inputs", b"inputs", "name", b"name", "task", b"task"]) -> None: ...

global___ExecuteUserConnectorRequest = ExecuteUserConnectorRequest

@typing_extensions.final
class ExecuteUserConnectorResponse(google.protobuf.message.Message):
    """ExecuteUserConnectorResponse contains the outcome of the execution."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUTS_FIELD_NUMBER: builtins.int
    @property
    def outputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """The execution outputs."""
    def __init__(
        self,
        *,
        outputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["outputs", b"outputs"]) -> None: ...

global___ExecuteUserConnectorResponse = ExecuteUserConnectorResponse

@typing_extensions.final
class TestUserConnectorRequest(google.protobuf.message.Message):
    """TestUserConnectorRequest represents a public request check the connection of
    a connector.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the connector, which allows its access by parent user
    and ID.
    - Format: `users/{user.id}/connectors/{connector.id}`.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___TestUserConnectorRequest = TestUserConnectorRequest

@typing_extensions.final
class TestUserConnectorResponse(google.protobuf.message.Message):
    """TestUserConnectorResponse contains the connection state."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATE_FIELD_NUMBER: builtins.int
    state: global___Connector.State.ValueType
    """The connector state."""
    def __init__(
        self,
        *,
        state: global___Connector.State.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["state", b"state"]) -> None: ...

global___TestUserConnectorResponse = TestUserConnectorResponse

@typing_extensions.final
class WatchUserConnectorRequest(google.protobuf.message.Message):
    """WatchUserConnectorRequest represents a request to fetch the state of a
    user-owned connector.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the connector, which allows its access by parent
    connector and ID.
    - Format: `users/{user.id}/connectors/{connector.id}`.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___WatchUserConnectorRequest = WatchUserConnectorRequest

@typing_extensions.final
class WatchUserConnectorResponse(google.protobuf.message.Message):
    """WatchUserConnectorResponse contains the connector current state."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATE_FIELD_NUMBER: builtins.int
    state: global___Connector.State.ValueType
    """The connector state."""
    def __init__(
        self,
        *,
        state: global___Connector.State.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["state", b"state"]) -> None: ...

global___WatchUserConnectorResponse = WatchUserConnectorResponse

@typing_extensions.final
class CreateOrganizationConnectorRequest(google.protobuf.message.Message):
    """CreateOrganizationConnectorRequest represents a request from an organization
    to create a connector.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    @property
    def connector(self) -> global___Connector:
        """The properties of the connector to be created."""
    parent: builtins.str
    """The parent resource, i.e., the organization that creates the connector.
    - Format: `organizations/{organization.id}`.
    """
    def __init__(
        self,
        *,
        connector: global___Connector | None = ...,
        parent: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector", b"connector", "parent", b"parent"]) -> None: ...

global___CreateOrganizationConnectorRequest = CreateOrganizationConnectorRequest

@typing_extensions.final
class CreateOrganizationConnectorResponse(google.protobuf.message.Message):
    """CreateOrganizationConnectorResponse contains the created connector."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_FIELD_NUMBER: builtins.int
    @property
    def connector(self) -> global___Connector:
        """The created connector resource."""
    def __init__(
        self,
        *,
        connector: global___Connector | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> None: ...

global___CreateOrganizationConnectorResponse = CreateOrganizationConnectorResponse

@typing_extensions.final
class ListOrganizationConnectorsRequest(google.protobuf.message.Message):
    """ListOrganizationConnectorsRequest represents a request to list the
    connectors of an organization.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    SHOW_DELETED_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of connectors to return. If this parameter is
    unspecified, at most 10 connectors will be returned. The cap value for this
    parameter is 100 (i.e. any value above that will be coerced to 100).
    """
    page_token: builtins.str
    """Page token."""
    view: global___Connector.View.ValueType
    """View allows clients to specify the desired resource view in the response."""
    filter: builtins.str
    """Filter expression to list connectors"""
    parent: builtins.str
    """The parent resource, i.e., the organization that created the connectors.
    - Format: `organizations/{organization.id}`.
    """
    show_deleted: builtins.bool
    """Include soft-deleted connectors in the result."""
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        view: global___Connector.View.ValueType | None = ...,
        filter: builtins.str | None = ...,
        parent: builtins.str = ...,
        show_deleted: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "_show_deleted", b"_show_deleted", "_view", b"_view", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "show_deleted", b"show_deleted", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "_show_deleted", b"_show_deleted", "_view", b"_view", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "parent", b"parent", "show_deleted", b"show_deleted", "view", b"view"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_token", b"_page_token"]) -> typing_extensions.Literal["page_token"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_show_deleted", b"_show_deleted"]) -> typing_extensions.Literal["show_deleted"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___ListOrganizationConnectorsRequest = ListOrganizationConnectorsRequest

@typing_extensions.final
class ListOrganizationConnectorsResponse(google.protobuf.message.Message):
    """ListOrganizationConnectorsResponse contains a list of connectors."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTORS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    @property
    def connectors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Connector]:
        """A list of connector resources."""
    next_page_token: builtins.str
    """Next page token."""
    total_size: builtins.int
    """Total count of connectors"""
    def __init__(
        self,
        *,
        connectors: collections.abc.Iterable[global___Connector] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["connectors", b"connectors", "next_page_token", b"next_page_token", "total_size", b"total_size"]) -> None: ...

global___ListOrganizationConnectorsResponse = ListOrganizationConnectorsResponse

@typing_extensions.final
class GetOrganizationConnectorRequest(google.protobuf.message.Message):
    """GetOrganizationConnectorRequest represents a request to fetch the details of
    a connector owned by an organization.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the connector, which allows its access by parent
    organization and ID.
    - Format: `organizations/{organization.id}/connectors/{connector.id}`.
    """
    view: global___Connector.View.ValueType
    """View allows clients to specify the desired resource view in the response."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        view: global___Connector.View.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_view", b"_view", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_view", b"_view", "name", b"name", "view", b"view"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___GetOrganizationConnectorRequest = GetOrganizationConnectorRequest

@typing_extensions.final
class GetOrganizationConnectorResponse(google.protobuf.message.Message):
    """GetOrganizationConnectorResponse contains the requested connector."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_FIELD_NUMBER: builtins.int
    @property
    def connector(self) -> global___Connector:
        """The connector resource."""
    def __init__(
        self,
        *,
        connector: global___Connector | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> None: ...

global___GetOrganizationConnectorResponse = GetOrganizationConnectorResponse

@typing_extensions.final
class UpdateOrganizationConnectorRequest(google.protobuf.message.Message):
    """UpdateOrganizationConnectorRequest represents a request to update a
    connector owned by an organization.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    @property
    def connector(self) -> global___Connector:
        """The connector fields that will replace the existing ones."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """The update mask specifies the subset of fields that should be modified.

        For more information about this field, see
        https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#field-mask.
        """
    def __init__(
        self,
        *,
        connector: global___Connector | None = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector", b"connector", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector", b"connector", "update_mask", b"update_mask"]) -> None: ...

global___UpdateOrganizationConnectorRequest = UpdateOrganizationConnectorRequest

@typing_extensions.final
class UpdateOrganizationConnectorResponse(google.protobuf.message.Message):
    """UpdateOrganizationConnectorResponse contains the updated connector."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_FIELD_NUMBER: builtins.int
    @property
    def connector(self) -> global___Connector:
        """The updated connector resource."""
    def __init__(
        self,
        *,
        connector: global___Connector | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> None: ...

global___UpdateOrganizationConnectorResponse = UpdateOrganizationConnectorResponse

@typing_extensions.final
class DeleteOrganizationConnectorRequest(google.protobuf.message.Message):
    """DeleteOrganizationConnectorRequest represents a request to delete a
    connector owned by an organization.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the connector, which allows its access by parent
    organization and ID.
    - Format: `organizations/{organization.id}/connectors/{connector.id}`.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DeleteOrganizationConnectorRequest = DeleteOrganizationConnectorRequest

@typing_extensions.final
class DeleteOrganizationConnectorResponse(google.protobuf.message.Message):
    """DeleteOrganizationConnectorResponse is an empty response."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteOrganizationConnectorResponse = DeleteOrganizationConnectorResponse

@typing_extensions.final
class ConnectOrganizationConnectorRequest(google.protobuf.message.Message):
    """ConnectOrganizationConnectorRequest represents a request to connect a
    connector owned by an organization.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the connector, which allows its access by parent
    organization and ID.
    - Format: `organizations/{organization.id}/connectors/{connector.id}`.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___ConnectOrganizationConnectorRequest = ConnectOrganizationConnectorRequest

@typing_extensions.final
class ConnectOrganizationConnectorResponse(google.protobuf.message.Message):
    """ConnectOrganizationConnectorResponse contains the connector details."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_FIELD_NUMBER: builtins.int
    @property
    def connector(self) -> global___Connector:
        """The connector resource."""
    def __init__(
        self,
        *,
        connector: global___Connector | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> None: ...

global___ConnectOrganizationConnectorResponse = ConnectOrganizationConnectorResponse

@typing_extensions.final
class DisconnectOrganizationConnectorRequest(google.protobuf.message.Message):
    """DisconnectOrganizationConnectorRequest represents a request to disconnect a
    connector owned by an organization.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the connector, which allows its access by parent
    organization and ID.
    - Format: `organizations/{organization.id}/connectors/{connector.id}`.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DisconnectOrganizationConnectorRequest = DisconnectOrganizationConnectorRequest

@typing_extensions.final
class DisconnectOrganizationConnectorResponse(google.protobuf.message.Message):
    """DisconnectOrganizationConnectorResponse contains the connector details."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_FIELD_NUMBER: builtins.int
    @property
    def connector(self) -> global___Connector:
        """A connector"""
    def __init__(
        self,
        *,
        connector: global___Connector | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> None: ...

global___DisconnectOrganizationConnectorResponse = DisconnectOrganizationConnectorResponse

@typing_extensions.final
class RenameOrganizationConnectorRequest(google.protobuf.message.Message):
    """RenameOrganizationConnectorRequest represents a request to rename the name
    of a connector owned by an organization.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    NEW_CONNECTOR_ID_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the connector, which allows its access by parent
    organization and ID.
    - Format: `organizations/{organization.id}/connectors/{connector.id}`.
    """
    new_connector_id: builtins.str
    """The new resource ID. This will transform the resource name into
    `organizations/{organization.id}/connectors/{new_connector_id}`.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        new_connector_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "new_connector_id", b"new_connector_id"]) -> None: ...

global___RenameOrganizationConnectorRequest = RenameOrganizationConnectorRequest

@typing_extensions.final
class RenameOrganizationConnectorResponse(google.protobuf.message.Message):
    """RenameOrganizationConnectorResponse contains a renamed connector."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_FIELD_NUMBER: builtins.int
    @property
    def connector(self) -> global___Connector:
        """The renamed connector resource."""
    def __init__(
        self,
        *,
        connector: global___Connector | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> None: ...

global___RenameOrganizationConnectorResponse = RenameOrganizationConnectorResponse

@typing_extensions.final
class ExecuteOrganizationConnectorRequest(google.protobuf.message.Message):
    """ExecuteOrganizationConnectorRequest represents a request to execute a
    connector owned by an organization.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    TASK_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the connector, which allows its access by parent
    organization and ID.
    - Format: `organizations/{organization.id}/connectors/{connector.id}`.
    """
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Connector input parameters."""
    task: builtins.str
    """Task to be passed to the connector (e.g. `TASK_TEXT_GENERATION`)."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        inputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
        task: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["inputs", b"inputs", "name", b"name", "task", b"task"]) -> None: ...

global___ExecuteOrganizationConnectorRequest = ExecuteOrganizationConnectorRequest

@typing_extensions.final
class ExecuteOrganizationConnectorResponse(google.protobuf.message.Message):
    """ExecuteOrganizationConnectorResponse contains the outcome of the execution."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUTS_FIELD_NUMBER: builtins.int
    @property
    def outputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """The execution outputs."""
    def __init__(
        self,
        *,
        outputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["outputs", b"outputs"]) -> None: ...

global___ExecuteOrganizationConnectorResponse = ExecuteOrganizationConnectorResponse

@typing_extensions.final
class TestOrganizationConnectorRequest(google.protobuf.message.Message):
    """TestOrganizationConnectorRequest represents a public request check the
    connection of a connector.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the connector, which allows its access by parent
    organization and ID.
    - Format: `organizations/{organization.id}/connectors/{connector.id}`.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___TestOrganizationConnectorRequest = TestOrganizationConnectorRequest

@typing_extensions.final
class TestOrganizationConnectorResponse(google.protobuf.message.Message):
    """TestOrganizationConnectorResponse contains the connection state."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATE_FIELD_NUMBER: builtins.int
    state: global___Connector.State.ValueType
    """The connector state."""
    def __init__(
        self,
        *,
        state: global___Connector.State.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["state", b"state"]) -> None: ...

global___TestOrganizationConnectorResponse = TestOrganizationConnectorResponse

@typing_extensions.final
class WatchOrganizationConnectorRequest(google.protobuf.message.Message):
    """WatchOrganizationConnectorRequest represents a request to fetch the state of
    an organization-owned connector.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the connector, which allows its access by parent
    connector and ID.
    - Format: `organizations/{organization.id}/connectors/{connector.id}`.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___WatchOrganizationConnectorRequest = WatchOrganizationConnectorRequest

@typing_extensions.final
class WatchOrganizationConnectorResponse(google.protobuf.message.Message):
    """WatchOrganizationConnectorResponse contains the connector current state."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATE_FIELD_NUMBER: builtins.int
    state: global___Connector.State.ValueType
    """The connector state."""
    def __init__(
        self,
        *,
        state: global___Connector.State.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["state", b"state"]) -> None: ...

global___WatchOrganizationConnectorResponse = WatchOrganizationConnectorResponse

@typing_extensions.final
class ListConnectorsAdminRequest(google.protobuf.message.Message):
    """========== Private endpoints

    ListConnectorsAdminRequest represents a request by an admin to list all
    connectors. Admin users have access to connectors from any user.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    SHOW_DELETED_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of connectors to return. If this parameter is
    unspecified, at most 10 connectors will be returned. The cap value for this
    parameter is 100 (i.e. any value above that will be coerced to 100).
    """
    page_token: builtins.str
    """Page token."""
    view: global___Connector.View.ValueType
    """View allows clients to specify the desired connector view in the response."""
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter
    expression.
    - Example: `create_time>timestamp("2000-06-19T23:31:08.657Z")`.
    """
    show_deleted: builtins.bool
    """Include soft-deleted connectors in the result."""
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        view: global___Connector.View.ValueType | None = ...,
        filter: builtins.str | None = ...,
        show_deleted: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "_show_deleted", b"_show_deleted", "_view", b"_view", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "show_deleted", b"show_deleted", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "_show_deleted", b"_show_deleted", "_view", b"_view", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "show_deleted", b"show_deleted", "view", b"view"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_token", b"_page_token"]) -> typing_extensions.Literal["page_token"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_show_deleted", b"_show_deleted"]) -> typing_extensions.Literal["show_deleted"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___ListConnectorsAdminRequest = ListConnectorsAdminRequest

@typing_extensions.final
class ListConnectorsAdminResponse(google.protobuf.message.Message):
    """ListConnectorsAdminResponse contains a list of connectors requested by an
    admin.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTORS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    @property
    def connectors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Connector]:
        """A list of connector resources."""
    next_page_token: builtins.str
    """Next page token."""
    total_size: builtins.int
    """Total number of connectors."""
    def __init__(
        self,
        *,
        connectors: collections.abc.Iterable[global___Connector] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["connectors", b"connectors", "next_page_token", b"next_page_token", "total_size", b"total_size"]) -> None: ...

global___ListConnectorsAdminResponse = ListConnectorsAdminResponse

@typing_extensions.final
class LookUpConnectorAdminRequest(google.protobuf.message.Message):
    """LookUpConnectorAdminRequest represents a request to query a
    connector via permalink by admin.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PERMALINK_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    permalink: builtins.str
    """Permalink of a connector. For example:
    "connectors/{uid}"
    """
    view: global___Connector.View.ValueType
    """View allows clients to specify the desired resource view in the response."""
    def __init__(
        self,
        *,
        permalink: builtins.str = ...,
        view: global___Connector.View.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_view", b"_view", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_view", b"_view", "permalink", b"permalink", "view", b"view"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___LookUpConnectorAdminRequest = LookUpConnectorAdminRequest

@typing_extensions.final
class LookUpConnectorAdminResponse(google.protobuf.message.Message):
    """LookUpConnectorAdminResponse represents a response for a
    connector.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_FIELD_NUMBER: builtins.int
    @property
    def connector(self) -> global___Connector:
        """connector"""
    def __init__(
        self,
        *,
        connector: global___Connector | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector", b"connector"]) -> None: ...

global___LookUpConnectorAdminResponse = LookUpConnectorAdminResponse

@typing_extensions.final
class CheckConnectorRequest(google.protobuf.message.Message):
    """CheckConnectorRequest represents a request to check the current state of a
    connector.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PERMALINK_FIELD_NUMBER: builtins.int
    permalink: builtins.str
    """The permalink of the connector, which allows its access by UID.
    - Format: `connectors/{uid}`.
    """
    def __init__(
        self,
        *,
        permalink: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["permalink", b"permalink"]) -> None: ...

global___CheckConnectorRequest = CheckConnectorRequest

@typing_extensions.final
class CheckConnectorResponse(google.protobuf.message.Message):
    """CheckConnectorResponse contains the connector's current state."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATE_FIELD_NUMBER: builtins.int
    state: global___Connector.State.ValueType
    """Connector state."""
    def __init__(
        self,
        *,
        state: global___Connector.State.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["state", b"state"]) -> None: ...

global___CheckConnectorResponse = CheckConnectorResponse



# generated by datamodel-codegen:
#   filename:  image_task_draw_classification_input.json

from __future__ import annotations

from dataclasses import dataclass
from typing import Optional


@dataclass
class Input:
    category: str
    image: str
    score: float
    showScore: Optional[bool] = None



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core/mgmt/v1beta/mgmt_private_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from core.mgmt.v1beta import mgmt_pb2 as core_dot_mgmt_dot_v1beta_dot_mgmt__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+core/mgmt/v1beta/mgmt_private_service.proto\x12\x10\x63ore.mgmt.v1beta\x1a\x1b\x63ore/mgmt/v1beta/mgmt.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1bgoogle/api/visibility.proto2\x98\x0b\n\x12MgmtPrivateService\x12\x80\x01\n\x0eListUsersAdmin\x12\'.core.mgmt.v1beta.ListUsersAdminRequest\x1a(.core.mgmt.v1beta.ListUsersAdminResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/v1beta/admin/users\x12\x8a\x01\n\x0cGetUserAdmin\x12%.core.mgmt.v1beta.GetUserAdminRequest\x1a&.core.mgmt.v1beta.GetUserAdminResponse\"+\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1beta/admin/{name=users/*}\x12\xa4\x01\n\x0fLookUpUserAdmin\x12(.core.mgmt.v1beta.LookUpUserAdminRequest\x1a).core.mgmt.v1beta.LookUpUserAdminResponse\"<\xda\x41\tpermalink\x82\xd3\xe4\x93\x02*\x12(/v1beta/admin/{permalink=users/*}/lookUp\x12\xa0\x01\n\x16ListOrganizationsAdmin\x12/.core.mgmt.v1beta.ListOrganizationsAdminRequest\x1a\x30.core.mgmt.v1beta.ListOrganizationsAdminResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1beta/admin/organizations\x12\xaa\x01\n\x14GetOrganizationAdmin\x12-.core.mgmt.v1beta.GetOrganizationAdminRequest\x1a..core.mgmt.v1beta.GetOrganizationAdminResponse\"3\xda\x41\x04name\x82\xd3\xe4\x93\x02&\x12$/v1beta/admin/{name=organizations/*}\x12\xc4\x01\n\x17LookUpOrganizationAdmin\x12\x30.core.mgmt.v1beta.LookUpOrganizationAdminRequest\x1a\x31.core.mgmt.v1beta.LookUpOrganizationAdminResponse\"D\xda\x41\tpermalink\x82\xd3\xe4\x93\x02\x32\x12\x30/v1beta/admin/{permalink=organizations/*}/lookUp\x12\xbf\x01\n\x18GetUserSubscriptionAdmin\x12\x31.core.mgmt.v1beta.GetUserSubscriptionAdminRequest\x1a\x32.core.mgmt.v1beta.GetUserSubscriptionAdminResponse\"<\xda\x41\x06parent\x82\xd3\xe4\x93\x02-\x12+/v1beta/admin/{parent=users/*}/subscription\x12\xdf\x01\n GetOrganizationSubscriptionAdmin\x12\x39.core.mgmt.v1beta.GetOrganizationSubscriptionAdminRequest\x1a:.core.mgmt.v1beta.GetOrganizationSubscriptionAdminResponse\"D\xda\x41\x06parent\x82\xd3\xe4\x93\x02\x35\x12\x33/v1beta/admin/{parent=organizations/*}/subscription\x1a\x10\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNALB\xd0\x01\n\x14\x63om.core.mgmt.v1betaB\x17MgmtPrivateServiceProtoP\x01Z=github.com/instill-ai/protogen-go/core/mgmt/v1beta;mgmtv1beta\xa2\x02\x03\x43MX\xaa\x02\x10\x43ore.Mgmt.V1beta\xca\x02\x10\x43ore\\Mgmt\\V1beta\xe2\x02\x1c\x43ore\\Mgmt\\V1beta\\GPBMetadata\xea\x02\x12\x43ore::Mgmt::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core.mgmt.v1beta.mgmt_private_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024com.core.mgmt.v1betaB\027MgmtPrivateServiceProtoP\001Z=github.com/instill-ai/protogen-go/core/mgmt/v1beta;mgmtv1beta\242\002\003CMX\252\002\020Core.Mgmt.V1beta\312\002\020Core\\Mgmt\\V1beta\342\002\034Core\\Mgmt\\V1beta\\GPBMetadata\352\002\022Core::Mgmt::V1beta'
  _MGMTPRIVATESERVICE._options = None
  _MGMTPRIVATESERVICE._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL'
  _MGMTPRIVATESERVICE.methods_by_name['ListUsersAdmin']._options = None
  _MGMTPRIVATESERVICE.methods_by_name['ListUsersAdmin']._serialized_options = b'\202\323\344\223\002\025\022\023/v1beta/admin/users'
  _MGMTPRIVATESERVICE.methods_by_name['GetUserAdmin']._options = None
  _MGMTPRIVATESERVICE.methods_by_name['GetUserAdmin']._serialized_options = b'\332A\004name\202\323\344\223\002\036\022\034/v1beta/admin/{name=users/*}'
  _MGMTPRIVATESERVICE.methods_by_name['LookUpUserAdmin']._options = None
  _MGMTPRIVATESERVICE.methods_by_name['LookUpUserAdmin']._serialized_options = b'\332A\tpermalink\202\323\344\223\002*\022(/v1beta/admin/{permalink=users/*}/lookUp'
  _MGMTPRIVATESERVICE.methods_by_name['ListOrganizationsAdmin']._options = None
  _MGMTPRIVATESERVICE.methods_by_name['ListOrganizationsAdmin']._serialized_options = b'\202\323\344\223\002\035\022\033/v1beta/admin/organizations'
  _MGMTPRIVATESERVICE.methods_by_name['GetOrganizationAdmin']._options = None
  _MGMTPRIVATESERVICE.methods_by_name['GetOrganizationAdmin']._serialized_options = b'\332A\004name\202\323\344\223\002&\022$/v1beta/admin/{name=organizations/*}'
  _MGMTPRIVATESERVICE.methods_by_name['LookUpOrganizationAdmin']._options = None
  _MGMTPRIVATESERVICE.methods_by_name['LookUpOrganizationAdmin']._serialized_options = b'\332A\tpermalink\202\323\344\223\0022\0220/v1beta/admin/{permalink=organizations/*}/lookUp'
  _MGMTPRIVATESERVICE.methods_by_name['GetUserSubscriptionAdmin']._options = None
  _MGMTPRIVATESERVICE.methods_by_name['GetUserSubscriptionAdmin']._serialized_options = b'\332A\006parent\202\323\344\223\002-\022+/v1beta/admin/{parent=users/*}/subscription'
  _MGMTPRIVATESERVICE.methods_by_name['GetOrganizationSubscriptionAdmin']._options = None
  _MGMTPRIVATESERVICE.methods_by_name['GetOrganizationSubscriptionAdmin']._serialized_options = b'\332A\006parent\202\323\344\223\0025\0223/v1beta/admin/{parent=organizations/*}/subscription'
  _globals['_MGMTPRIVATESERVICE']._serialized_start=179
  _globals['_MGMTPRIVATESERVICE']._serialized_end=1611
# @@protoc_insertion_point(module_scope)
